@@ -1,6 +1,6 @@
 # tifffile/examples/earthbigdata.py
 
-# Copyright (c) 2021-2022, Christoph Gohlke
+# Copyright (c) 2021-2023, Christoph Gohlke
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -36,10 +36,9 @@
 """
 # Create a fsspec ReferenceFileSystem for a large set of remote GeoTIFF files
 
-by [Christoph Gohlke](https://www.lfd.uci.edu/~gohlke/),
-Laboratory for Fluorescence Dynamics, University of California, Irvine
+by [Christoph Gohlke](https://www.cgohlke.com)
 
-Updated on April 8, 2022
+Updated on July 4, 2023
 
 This Python script uses the [tifffile](https://github.com/cgohlke/tifffile) and
 [imagecodecs](https://github.com/cgohlke/imagecodecs) packages to create a
@@ -49,23 +48,22 @@ http://sentinel-1-global-coherence-earthbigdata.s3-website-us-west-2.amazonaws.c
 ) set, which consists of 1,033,422 GeoTIFF files stored on AWS.
 The ReferenceFileSystem is used to create a multi-dimensional Xarray dataset.
 
-See discussion at [kerchunk/issues/78](
+Refer to the discussion at [kerchunk/issues/78](
 https://github.com/fsspec/kerchunk/issues/78).
 """
 
 # %%
-import os
 import base64
+import os
 
-import tifffile
+import fsspec
 import imagecodecs.numcodecs
 import matplotlib.pyplot
 import numcodecs
-import fsspec
+import tifffile
 import xarray
 import zarr
 
-
 # %% [markdown]
 """
 ## Get a list of all remote TIFF files
@@ -82,7 +80,7 @@ if not os.path.exists('earthbigdata.txt'):
         ' --recursive > earthbigdata.txt'
     )
 
-with open('earthbigdata.txt') as fh:
+with open('earthbigdata.txt', encoding='utf-8') as fh:
     tiff_files = [
         line.split()[-1][11:] for line in fh.readlines() if '.tif' in line
     ]
@@ -183,7 +181,7 @@ flightdirection_pattern = (
 """
 
 # %%
-jsonfile = open('earthbigdata.json', 'w', newline='\n')
+jsonfile = open('earthbigdata.json', 'w', encoding='utf-8', newline='\n')
 
 # %% [markdown]
 """
@@ -524,17 +522,19 @@ Print information about the software used to run this script.
 
 # %%
 def system_info():
-    import sys
     import datetime
-    import numpy
-    import matplotlib
-    import tifffile
-    import imagecodecs
-    import numcodecs
+    import sys
+
     import fsspec
+    import imagecodecs
+    import matplotlib
+    import numcodecs
+    import numpy
     import xarray
     import zarr
 
+    import tifffile
+
     return '\n'.join(
         (
             sys.executable,
